@@ -660,7 +660,7 @@ mfxStatus VideoDECODEVVC::SubmitFrame(mfxBitstream* bs, mfxFrameSurface1* surfac
     {
         bool workSfsIsEmpty = IsSurfaceEmpty(*surface_work);
 
-        MFX_CHECK(!workSfsIsEmpty, MFX_ERR_LOCK_MEMORY);
+        MFX_CHECK(!workSfsIsEmpty, MFX_ERR_INVALID_VIDEO_PARAM);
 
         if (m_is_cscInUse != true)
         {
