@@ -47,6 +47,20 @@ namespace Base
     constexpr mfxU8  IDX_INVALID                = 0xff;
     constexpr mfxU8  HW_SURF_ALIGN_W            = 16;
     constexpr mfxU8  HW_SURF_ALIGN_H            = 16;
+
+    // Helper functions to get platform-specific alignment values at runtime
+    inline mfxU8 GetHWSurfAlignW(eMFXHWType hw)
+    {
+        return (hw == MFX_HW_BMG
+                ) ? 8 : HW_SURF_ALIGN_W;
+    }
+
+    inline mfxU8 GetHWSurfAlignH(eMFXHWType hw)
+    {
+        return (hw == MFX_HW_BMG
+                ) ? 8 : HW_SURF_ALIGN_H;
+    }
+
     constexpr mfxU16 MAX_SLICES                 = 600; // conforms to level 6 limits
     constexpr mfxU8  DEFAULT_LTR_INTERVAL       = 16;
     constexpr mfxU8  DEFAULT_PPYR_INTERVAL      = 3;
@@ -794,6 +808,7 @@ namespace Base
         Resource            BS;
         Resource            CUQP;
         mfxHDLPair          HDLRaw              = {};
+        mfxHDLPair          HDLLPLAData         = {};
         bool                bCUQPMap            = false;
 #if defined(MFX_ENABLE_ENCTOOLS_BASE)
         mfxLplastatus       LplaStatus          = {};
@@ -1378,6 +1393,7 @@ namespace Base
 #if defined(MFX_ENABLE_AI_ENC_CTRL)
         , FEATURE_AIENC
 #endif
+        , FEATURE_PADDING
         , NUM_FEATURES
     };
 
@@ -1420,6 +1436,7 @@ namespace Base
         using AllocBS             = StorageVar<__LINE__ - _KD, IAllocation>;
         using AllocMBQP           = StorageVar<__LINE__ - _KD, IAllocation>;
         using MBQPAllocInfo       = StorageVar<__LINE__ - _KD, MBQPAllocFrameInfo>;
+        using LplaDataBuffer      = StorageVar<__LINE__ - _KD, mfxFrameSurface1>;
         using PackedHeaders       = StorageVar<__LINE__ - _KD, Base::PackedHeaders>;
         using DDI_Resources       = StorageVar<__LINE__ - _KD, std::list<DDIExecParam>>;
         using DDI_SubmitParam     = StorageVar<__LINE__ - _KD, std::list<DDIExecParam>>;
