@@ -1,4 +1,4 @@
-// Copyright (c) 2018-2024 Intel Corporation
+// Copyright (c) 2018-2025 Intel Corporation
 //
 // Permission is hereby granted, free of charge, to any person obtaining a copy
 // of this software and associated documentation files (the "Software"), to deal
@@ -163,7 +163,9 @@ public:
 
     // Check HW property
     virtual void  GetVA(mfxHDL* phdl, mfxU16 type) = 0;
+    virtual void  GetVaArray(std::vector<mfxHDL>* phdl_array, mfxU16 type) = 0;
     virtual mfxStatus CreateVA(mfxVideoParam * , mfxFrameAllocRequest *, mfxFrameAllocResponse *, UMC::FrameAllocator *) = 0;
+    virtual mfxStatus CreateVaArray(mfxVideoParam*, mfxFrameAllocRequest*, mfxFrameAllocResponse*, UMC::FrameAllocator*, mfxU8) = 0;
     // Get the current working adapter's number
     virtual mfxU32 GetAdapterNumber(void) = 0;
 
@@ -449,7 +451,7 @@ public:
     }
 
     virtual
-    mfxU16 GetMemType(mfxVideoParam par)
+    mfxU16 GetMemType(const mfxVideoParam& par)
     {
         return mfxU16(par.IOPattern == MFX_IOPATTERN_IN_SYSTEM_MEMORY ? MFX_MEMTYPE_FROM_ENCODE | MFX_MEMTYPE_SYSTEM_MEMORY : MFX_MEMTYPE_FROM_ENCODE | MFX_MEMTYPE_DXVA2_DECODER_TARGET);
     }
@@ -513,6 +515,9 @@ public:
     virtual mfxStatus         GetSurface(mfxFrameSurface1* & surface, mfxSurfaceHeader* /*import_surface*/) { surface = nullptr; return MFX_ERR_UNSUPPORTED; }
     virtual mfxFrameSurface1* GetInternalSurface(mfxFrameSurface1 * /*surface*/) { return nullptr; }
 
+    // Get bitstream buffer in video memory for decode
+    virtual mfxStatus GetBitstreamBuffer(mfxBitstream* queried_bsBuffer) { (void)queried_bsBuffer; return MFX_ERR_UNSUPPORTED; }
+
     mfxStatus ResetCache(mfxVideoParam*) { return MFX_ERR_NONE; }
 };
 
